<?php
/**
 * Theme Customizer settings.
 *
 * @package Debut 
 * @since 1.7 
 */
/**
 * Theme customizer settings with real-time update
 * Very helpful: http://ottopress.com/2012/theme-customizer-part-deux-getting-rid-of-options-pages/
 *
 * @since 1.5
 */


function personnal_theme_customizer($wp_customize) {

    // Highlight and link color
    $wp_customize->add_setting('personnal_link_color', array(
        'default' => '#000000',
        'transport' => 'postMessage',
        'sanitize_callback' => 'sanitize_hex_color',
    ));

    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'personnal_link_color', array(
        'label' => __('Link and Highlight Color','personnal'),
        'section' => 'colors',
        'settings' => 'personnal_link_color',
    )));

    // Logo upload
    $wp_customize->add_section('personnal_logo_section', array(
        'title' => __('Logo', 'personnal'),
        'priority' => 30,
        'description' => __('Upload a logo to replace the default site name and description in the header','personnal'),
    ));

    $wp_customize->add_setting('personnal_logo', array(
        'sanitize_callback' => 'esc_url_raw',
    ));

    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'personnal_logo', array(
        'label' => __('Logo', 'personnal'),
        'section' => 'personnal_logo_section',
        'settings' => 'personnal_logo',
    )));
    $wp_customize->add_setting(
            'logo_placement', array(
        'default' => 'center',
        'sanitize_callback' => 'personnal_sanitize_logo_placement',
            )
    );

    $wp_customize->add_control(
            'logo_placement', array(
        'type' => 'radio',
        'label' => __('Logo placement','personnal'),
        'section' => 'personnal_logo_section',
        'choices' => array(
            'left' => 'Left',
            'right' => 'Right',
            'center' => 'Center',
        ),
            )
    );

    $wp_customize->add_setting('sidebar_position', array('default' => 'right',
        'sanitize_callback' => 'utopia_sanitize_sidebar_placement'));
    $wp_customize->add_control('sidebar_position', array(
        'label' => __('Sidebar position', 'personnal'),
        'section' => 'layout',
        'settings' => 'sidebar_position',
        'type' => 'radio',
        'choices' => array(
            'left' => 'left',
            'right' => 'right',
        ),
    ));
    $wp_customize->add_section('layout', array(
        'title' => __('Layout', 'personnal'),
    ));

    // Color Scheme
    $wp_customize->add_setting('personnal_customizer_sidebar_color', array(
        'default' => 'dark',
        'capability' => 'edit_theme_options',
        'type' => 'option',
        'sanitize_callback' => 'personnal_sanitize_scheme_select'
    ));

    $wp_customize->add_control('personnal_customizer_sidebar_color', array(
        'settings' => 'personnal_customizer_sidebar_color',
        'label' => __('Sidebar Color', 'personnal'),
        'section' => 'personnal_sidebar_color',
        'type' => 'select',
        'choices' => array(
            'dark' => __('Dark', 'personnal'),
            'light' => __('Light', 'personnal'),
        ),
    ));
    $wp_customize->add_section('personnal_sidebar_color', array(
        'title' => __('Sidebar Color', 'personnal'),
    ));


    $wp_customize->add_section('copyrigth_text', array(
        'title' => __('Copyrigth text', 'personnal')
    ));

    $wp_customize->add_setting(
            'copyright_textbox', array(
        'default' => __('Default copyright text','personnal'),
                'sanitize_callback' => 'personnal_sanitize_text',
            )
    );
    $wp_customize->add_control(
            'copyright_textbox', array(
        'label' => __('Copyright text','personnal'),
        'section' => 'copyrigth_text',
        'type' => 'text',
            )
    );

    $wp_customize->add_setting(
            'hide_copyright',array(
             'sanitize_callback' => 'personnal_sanitize_checkbox',
    ));

    $wp_customize->add_control(
            'hide_copyright', array(
        'type' => 'checkbox',
        'label' => __('Hide copyright text','personnal'),
        'section' => 'copyrigth_text',
            )
    );



    // Set site name and description to be previewed in real-time
//    $wp_customize->get_setting('blogname')->transport = 'postMessage';
//    $wp_customize->get_setting('blogdescription')->transport = 'postMessage';

    // Enqueue scripts for real-time preview
//    wp_enqueue_script('personnal-customizer', get_template_directory_uri() . '/js/personnal-customizer.js', array('jquery'));
}

add_action('customize_register', 'personnal_theme_customizer');

/**
 * Sanitizes a hex color. Identical to core's sanitize_hex_color(), which is not available on the wp_head hook.
 *
 * Returns either '', a 3 or 6 digit hex color (with #), or null.
 * For sanitizing values without a #, see sanitize_hex_color_no_hash().
 *
 * @since 1.7
 */
function personnal_sanitize_hex_color($color) {
    if ('' === $color)
        return '';

    // 3 or 6 hex digits, or the empty string.
    if (preg_match('|^#([A-Fa-f0-9]{3}){1,2}$|', $color))
        return $color;

    return null;
}

/**
 * Sanitizes our post content value (either excerpts or full post content).
 *
 * @since 1.7
 */
function personnal_sanitize_index_content($content) {
    if ('option2' == $content) {
        return 'option2';
    } else {
        return 'option1';
    }
}
/**
 * Sanitize select option
 */
function personnal_sanitize_scheme_select($input) {
    $valid = array(
        'dark' => __('Dark', 'personnal'),
        'light' => __('Light', 'personnal'),
    );

    if (array_key_exists($input, $valid)) {
        return $input;
    } else {
        return '';
    }
}function personnal_sanitize_text( $input ) {
    return wp_kses_post( force_balance_tags( $input ) );
}
function personnal_sanitize_logo_placement( $input ) {
    $valid = array(
        'left' => 'Left',
        'right' => 'Right',
        'center' => 'Center',
    );
 
    if ( array_key_exists( $input, $valid ) ) {
        return $input;
    } else {
        return '';
    }
}

function personnal_sanitize_checkbox( $input ) {
    if ( $input == 1 ) {
        return 1;
    } else {
        return '';
    }
}
/**
 * Add CSS in <head> for styles handled by the theme customizer
 *
 * @since 1.5
 */
function personnal_add_customizer_css() {
    $color = personnal_sanitize_hex_color(get_theme_mod('personnal_link_color'));
    ?>
    <!-- Debut customizer CSS -->
    <style>
        body {
            border-color: <?php echo $color; ?>
        }
         a:visited {
            color: <?php echo $color; ?>
        }
        .main-navigation a:hover,
        .main-navigation .sub-menu a:hover,
        .main-navigation .children a:hover,
        .main-navigation a:focus,
        .main-navigation a:active,
        .main-navigation .current-menu-item > a,
        .main-navigation .current_page_item > a,
        .personnal-lang:hover {
            background-color: <?php echo $color; ?>
        }
    </style>
    <?php
}

add_action('wp_head', 'personnal_add_customizer_css');